<?php

namespace Realestate\Seo\Policies;

use Litepie\User\Contracts\UserPolicy;
use Realestate\Seo\Models\Seo;

class SeoPolicy
{

    /**
     * Determine if the given user can view the seo.
     *
     * @param UserPolicy $user
     * @param Seo $seo
     *
     * @return bool
     */
    public function view(UserPolicy $user, Seo $seo)
    {
        if ($user->canDo('seo.seo.view') && $user->isAdmin()) {
            return true;
        }

        return $seo->user_id == user_id() && $seo->user_type == user_type();
    }

    /**
     * Determine if the given user can create a seo.
     *
     * @param UserPolicy $user
     * @param Seo $seo
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('seo.seo.create');
    }

    /**
     * Determine if the given user can update the given seo.
     *
     * @param UserPolicy $user
     * @param Seo $seo
     *
     * @return bool
     */
    public function update(UserPolicy $user, Seo $seo)
    {
        if ($user->canDo('seo.seo.edit') && $user->isAdmin()) {
            return true;
        }

        return $seo->user_id == user_id() && $seo->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given seo.
     *
     * @param UserPolicy $user
     * @param Seo $seo
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Seo $seo)
    {
        return $seo->user_id == user_id() && $seo->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given seo.
     *
     * @param UserPolicy $user
     * @param Seo $seo
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Seo $seo)
    {
        if ($user->canDo('seo.seo.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given seo.
     *
     * @param UserPolicy $user
     * @param Seo $seo
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Seo $seo)
    {
        if ($user->canDo('seo.seo.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
